Python Octavia Client Reference
===============================

The following is a mapping between legacy Neutron CLIs and
the Octavia plugin into OSC. Think of it as a magic decoder ring if you were
using the legacy CLIs and want to transition to OpenStack CLI.
Command options are only shown when necessary.

Mapping Guide - LBaaS v2 CLI
----------------------------

.. csv-table::
   :header: "Neutron CLI", "OSC Equivalent", "Description"
   :widths: 30, 30, 40
   :file: data/lbaas.csv

.. note::
    As commands get introduced they will populate the table.
    If no OSC Equivalent commands are listed, the command has not been
    implemented yet.
